==> estateplat-common-1.2.4-20210521.015936-773-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDyaq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产抵押权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_dyaq")
public class BdcDyaq extends QllxParent implements QllxVo {
    //    private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id
    private String dw;//单位
    private String zwr;//债务人
    private String dyfs;//抵押方式
    private String zjgczl;//在建工程坐落
    private String zjgcdyfw;//在建工程抵押范围


    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押原因
    private Date zxsj;//注销时间
    private String zxdbr;//注销登簿人
    //    private Integer iszx;//是否注销
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String fj;//附记
    //    private String bh;//编号
    private Integer qszt;//权属状态
    private String dbfw;//担保范围
    private Integer dysw;//抵押顺位
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private Double bdbzzqse;//被担保主债权数额（最高债权数额）
    private String dkfs;//贷款方式
    private String qlsx;//权利顺序

    private String jezl;//金额种类
    private String qt;//其他
    private Double fwpgjg;//房屋评估价格
    private Double tdpgjg;//土地评估价格
    private Double fwdyjg;//房屋抵押价格
    private Double tddyjg;//土地抵押价格
    private String ysxkzmh;//预售许可证明号
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积

    private Double tddymj;//土地抵押面积
    private Double fwdymj;//房屋抵押面积

    private String dyhtbh;//抵押合同编号

    private String sfgtdb;//是否共同担保

    private Double sydyje;//剩余抵押金额
    private Double sydymj;//剩余抵押面积

    private String sfrz;//是否融资
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销
    private Double bdbzzqsesum;//被担保主债权数额（最高债权数额）总和
    private Double tddymjsum;//土地抵押面积
    private Double fwdymjsum;//房屋抵押面积

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fwfzxx表增加冗余字段dyr、dyrzjzl、dyrzjh、dyqr、dyqrzjzl、dyqrzjh、bdcqzh、bdcqzmh、bdcdyh、bdcdybh、zl
     */
    private String dyr; //抵押人

    private String dyrzjzl; //抵押人证件种类

    private String dyrzjh; //抵押人证件号

    private String dyqr;  //抵押权人

    private String dyqrzjzl; //抵押权人证件种类

    private String dyqrzjh; //抵押权人证件号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号

    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况
    private String dybdclx;//抵押不动产类型
    private String fcqdh; //房产丘地号

    private String dblx;//担保类型

    private Date dyslrq;//抵押设立日期
    private String sfxzzr;//是否限制转让
    private Double zgzqe;//最高债权额

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }

    public Double getZgzqe() {
        return zgzqe;
    }

    public void setZgzqe(Double zgzqe) {
        this.zgzqe = zgzqe;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyrzjzl() {
        return dyrzjzl;
    }

    public void setDyrzjzl(String dyrzjzl) {
        this.dyrzjzl = dyrzjzl;
    }

    public String getDyrzjh() {
        return dyrzjh;
    }

    public void setDyrzjh(String dyrzjh) {
        this.dyrzjh = dyrzjh;
    }

    public String getDyqr() {
        return dyqr;
    }

    public void setDyqr(String dyqr) {
        this.dyqr = dyqr;
    }

    public String getDyqrzjzl() {
        return dyqrzjzl;
    }

    public void setDyqrzjzl(String dyqrzjzl) {
        this.dyqrzjzl = dyqrzjzl;
    }

    public String getDyqrzjh() {
        return dyqrzjh;
    }

    public void setDyqrzjh(String dyqrzjh) {
        this.dyqrzjh = dyqrzjh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getSfgtdb() {
        return sfgtdb;
    }

    public void setSfgtdb(String sfgtdb) {
        this.sfgtdb = sfgtdb;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getYsxkzmh() {
        return ysxkzmh;
    }

    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }


    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public Integer getDysw() {
        return dysw;
    }

    public void setDysw(Integer dysw) {
        this.dysw = dysw;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }


    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }


    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public String getQlsx() {
        return qlsx;
    }

    public void setQlsx(String qlsx) {
        this.qlsx = qlsx;
    }

    public String getJezl() {
        return jezl;
    }

    public void setJezl(String jezl) {
        this.jezl = jezl;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public Double getFwpgjg() {
        return fwpgjg;
    }

    public void setFwpgjg(Double fwpgjg) {
        this.fwpgjg = fwpgjg;
    }

    public Double getTdpgjg() {
        return tdpgjg;
    }

    public void setTdpgjg(Double tdpgjg) {
        this.tdpgjg = tdpgjg;
    }

    public Double getFwdyjg() {
        return fwdyjg;
    }

    public void setFwdyjg(Double fwdyjg) {
        this.fwdyjg = fwdyjg;
    }

    public Double getTddyjg() {
        return tddyjg;
    }

    public void setTddyjg(Double tddyjg) {
        this.tddyjg = tddyjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getFwdymj() {
        return fwdymj;
    }

    public void setFwdymj(Double fwdymj) {
        this.fwdymj = fwdymj;
    }

    public Double getTddymj() {
        return tddymj;
    }

    public void setTddymj(Double tddymj) {
        this.tddymj = tddymj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getSydyje() {
        return sydyje;
    }

    public void setSydyje(Double sydyje) {
        this.sydyje = sydyje;
    }

    public Double getSydymj() {
        return sydymj;
    }

    public void setSydymj(Double sydymj) {
        this.sydymj = sydymj;
    }

    public String getSfrz() {
        return sfrz;
    }

    public void setSfrz(String sfrz) {
        this.sfrz = sfrz;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public String getFcqdh() {
        return fcqdh;
    }

    public void setFcqdh(String fcqdh) {
        this.fcqdh = fcqdh;
    }

    public Double getBdbzzqsesum() {
        return bdbzzqsesum;
    }

    public void setBdbzzqsesum(Double bdbzzqsesum) {
        this.bdbzzqsesum = bdbzzqsesum;
    }

    public Double getTddymjsum() {
        return tddymjsum;
    }

    public void setTddymjsum(Double tddymjsum) {
        this.tddymjsum = tddymjsum;
    }

    public Double getFwdymjsum() {
        return fwdymjsum;
    }

    public void setFwdymjsum(Double fwdymjsum) {
        this.fwdymjsum = fwdymjsum;
    }

    public String getDblx() {
        return dblx;
    }

    public void setDblx(String dblx) {
        this.dblx = dblx;
    }

    public Date getDyslrq() {
        return dyslrq;
    }

    public void setDyslrq(Date dyslrq) {
        this.dyslrq = dyslrq;
    }

}

==> estateplat-common-1.2.4-20210909.114104-864-sources.jar: cn/gtmap/estateplat/model/server/core/BdcDyaq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产抵押权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_dyaq")
public class BdcDyaq extends QllxParent implements QllxVo {
    //    private String qlid;//权利Id
    //    private String bdcdyid;//不动产单元Id
    private String dw;//单位
    private String zwr;//债务人
    private String dyfs;//抵押方式
    private String zjgczl;//在建工程坐落
    private String zjgcdyfw;//在建工程抵押范围


    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押原因
    private Date zxsj;//注销时间
    private String zxdbr;//注销登簿人
    //    private Integer iszx;//是否注销
    private String ywh;//业务号
    private String qllx;//权利类型
    //    private String proid;//项目ID
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String fj;//附记
    //    private String bh;//编号
    private Integer qszt;//权属状态
    private String dbfw;//担保范围
    private Integer dysw;//抵押顺位
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private Double bdbzzqse;//被担保主债权数额（最高债权数额）
    private String dkfs;//贷款方式
    private String qlsx;//权利顺序

    private String jezl;//金额种类
    private String qt;//其他
    private Double fwpgjg;//房屋评估价格
    private Double tdpgjg;//土地评估价格
    private Double fwdyjg;//房屋抵押价格
    private Double tddyjg;//土地抵押价格
    private String ysxkzmh;//预售许可证明号
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积

    private Double tddymj;//土地抵押面积
    private Double fwdymj;//房屋抵押面积

    private String dyhtbh;//抵押合同编号

    private String sfgtdb;//是否共同担保

    private Double sydyje;//剩余抵押金额
    private Double sydymj;//剩余抵押面积

    private String sfrz;//是否融资
    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销
    private Double bdbzzqsesum;//被担保主债权数额（最高债权数额）总和
    private Double tddymjsum;//土地抵押面积
    private Double fwdymjsum;//房屋抵押面积

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_fwfzxx表增加冗余字段dyr、dyrzjzl、dyrzjh、dyqr、dyqrzjzl、dyqrzjh、bdcqzh、bdcqzmh、bdcdyh、bdcdybh、zl
     */
    private String dyr; //抵押人

    private String dyrzjzl; //抵押人证件种类

    private String dyrzjh; //抵押人证件号

    private String dyqr;  //抵押权人

    private String dyqrzjzl; //抵押权人证件种类

    private String dyqrzjh; //抵押权人证件号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号

    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况
    private String dybdclx;//抵押不动产类型
    private String fcqdh; //房产丘地号

    private String dblx;//担保类型

    private Date dyslrq;//抵押设立日期
    private String sfxzzr;//是否限制转让
    private Double zgzqe;//最高债权额

    private String dyjelx;//抵押金额类型 “0”表示单个不动产单元独立抵押金额，“1”表示多个不动产单元整体抵押金额'
    private String jedw;//金额单位 字典表bdc_zd_jedw

    public String getDyjelx() {
        return dyjelx;
    }

    public void setDyjelx(String dyjelx) {
        this.dyjelx = dyjelx;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }

    public Double getZgzqe() {
        return zgzqe;
    }

    public void setZgzqe(Double zgzqe) {
        this.zgzqe = zgzqe;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyrzjzl() {
        return dyrzjzl;
    }

    public void setDyrzjzl(String dyrzjzl) {
        this.dyrzjzl = dyrzjzl;
    }

    public String getDyrzjh() {
        return dyrzjh;
    }

    public void setDyrzjh(String dyrzjh) {
        this.dyrzjh = dyrzjh;
    }

    public String getDyqr() {
        return dyqr;
    }

    public void setDyqr(String dyqr) {
        this.dyqr = dyqr;
    }

    public String getDyqrzjzl() {
        return dyqrzjzl;
    }

    public void setDyqrzjzl(String dyqrzjzl) {
        this.dyqrzjzl = dyqrzjzl;
    }

    public String getDyqrzjh() {
        return dyqrzjh;
    }

    public void setDyqrzjh(String dyqrzjh) {
        this.dyqrzjh = dyqrzjh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getSfgtdb() {
        return sfgtdb;
    }

    public void setSfgtdb(String sfgtdb) {
        this.sfgtdb = sfgtdb;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getYsxkzmh() {
        return ysxkzmh;
    }

    public void setYsxkzmh(String ysxkzmh) {
        this.ysxkzmh = ysxkzmh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }


    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public Integer getDysw() {
        return dysw;
    }

    public void setDysw(Integer dysw) {
        this.dysw = dysw;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }


    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }


    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }


    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public String getQlsx() {
        return qlsx;
    }

    public void setQlsx(String qlsx) {
        this.qlsx = qlsx;
    }

    public String getJezl() {
        return jezl;
    }

    public void setJezl(String jezl) {
        this.jezl = jezl;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public Double getFwpgjg() {
        return fwpgjg;
    }

    public void setFwpgjg(Double fwpgjg) {
        this.fwpgjg = fwpgjg;
    }

    public Double getTdpgjg() {
        return tdpgjg;
    }

    public void setTdpgjg(Double tdpgjg) {
        this.tdpgjg = tdpgjg;
    }

    public Double getFwdyjg() {
        return fwdyjg;
    }

    public void setFwdyjg(Double fwdyjg) {
        this.fwdyjg = fwdyjg;
    }

    public Double getTddyjg() {
        return tddyjg;
    }

    public void setTddyjg(Double tddyjg) {
        this.tddyjg = tddyjg;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getFwdymj() {
        return fwdymj;
    }

    public void setFwdymj(Double fwdymj) {
        this.fwdymj = fwdymj;
    }

    public Double getTddymj() {
        return tddymj;
    }

    public void setTddymj(Double tddymj) {
        this.tddymj = tddymj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getSydyje() {
        return sydyje;
    }

    public void setSydyje(Double sydyje) {
        this.sydyje = sydyje;
    }

    public Double getSydymj() {
        return sydymj;
    }

    public void setSydymj(Double sydymj) {
        this.sydymj = sydymj;
    }

    public String getSfrz() {
        return sfrz;
    }

    public void setSfrz(String sfrz) {
        this.sfrz = sfrz;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public String getFcqdh() {
        return fcqdh;
    }

    public void setFcqdh(String fcqdh) {
        this.fcqdh = fcqdh;
    }

    public Double getBdbzzqsesum() {
        return bdbzzqsesum;
    }

    public void setBdbzzqsesum(Double bdbzzqsesum) {
        this.bdbzzqsesum = bdbzzqsesum;
    }

    public Double getTddymjsum() {
        return tddymjsum;
    }

    public void setTddymjsum(Double tddymjsum) {
        this.tddymjsum = tddymjsum;
    }

    public Double getFwdymjsum() {
        return fwdymjsum;
    }

    public void setFwdymjsum(Double fwdymjsum) {
        this.fwdymjsum = fwdymjsum;
    }

    public String getDblx() {
        return dblx;
    }

    public void setDblx(String dblx) {
        this.dblx = dblx;
    }

    public Date getDyslrq() {
        return dyslrq;
    }

    public void setDyslrq(Date dyslrq) {
        this.dyslrq = dyslrq;
    }

}
